Chiplotle Geometry / Shapes
============================

Shapes
--------

.. autofunction:: chiplotle.geometry.shapes.annotation
.. autofunction:: chiplotle.geometry.shapes.arc_circle
.. autofunction:: chiplotle.geometry.shapes.arc_ellipse
.. autofunction:: chiplotle.geometry.shapes.arrow
.. autofunction:: chiplotle.geometry.shapes.bezier_path
.. autofunction:: chiplotle.geometry.shapes.catmull_path
.. autofunction:: chiplotle.geometry.shapes.circle
.. autofunction:: chiplotle.geometry.shapes.cross
.. autofunction:: chiplotle.geometry.shapes.donut
.. autofunction:: chiplotle.geometry.shapes.ellipse
.. autofunction:: chiplotle.geometry.shapes.fan
.. autofunction:: chiplotle.geometry.shapes.frame
.. autofunction:: chiplotle.geometry.shapes.grid
.. autofunction:: chiplotle.geometry.shapes.group
.. autofunction:: chiplotle.geometry.shapes.isosceles
.. autofunction:: chiplotle.geometry.shapes.label
.. autofunction:: chiplotle.geometry.shapes.layer
.. autofunction:: chiplotle.geometry.shapes.line
.. autofunction:: chiplotle.geometry.shapes.line_displaced
.. autofunction:: chiplotle.geometry.shapes.lock_group
.. autofunction:: chiplotle.geometry.shapes.path
.. autofunction:: chiplotle.geometry.shapes.path_linear
.. autofunction:: chiplotle.geometry.shapes.radial_ruler
.. autofunction:: chiplotle.geometry.shapes.random_walk_cartesian
.. autofunction:: chiplotle.geometry.shapes.random_walk_polar
.. autofunction:: chiplotle.geometry.shapes.rectangle
.. autofunction:: chiplotle.geometry.shapes.ruler
.. autofunction:: chiplotle.geometry.shapes.spiral_archimedean
.. autofunction:: chiplotle.geometry.shapes.spiral_logarithmic
.. autofunction:: chiplotle.geometry.shapes.square
.. autofunction:: chiplotle.geometry.shapes.star_crisscross
.. autofunction:: chiplotle.geometry.shapes.star_outline
.. autofunction:: chiplotle.geometry.shapes.supershape
.. autofunction:: chiplotle.geometry.shapes.symmetric_polygon_side_length
.. autofunction:: chiplotle.geometry.shapes.target

Transforms
-------------

.. autofunction:: chiplotle.geometry.transforms.TransformVisitor
.. autofunction:: chiplotle.geometry.transforms.arrange_shapes_on_path
.. autofunction:: chiplotle.geometry.transforms.center_at
.. autofunction:: chiplotle.geometry.transforms.noise
.. autofunction:: chiplotle.geometry.transforms.offset
.. autofunction:: chiplotle.geometry.transforms.perpendicular_displace
.. autofunction:: chiplotle.geometry.transforms.perpendicular_noise
.. autofunction:: chiplotle.geometry.transforms.rotate
.. autofunction:: chiplotle.geometry.transforms.scale

